@@ -104,7 +104,7 @@ IP: str = sys.argv[1]
 Port: int = int(sys.argv[2])
 utils.CheckNetworkConnection(IP, Port)
 Subcommand: str = sys.argv[3]
-SubcommandArgs: List[str] = []]
+SubcommandArgs: List[str] = []
 
 i: int = 0
 for x in range(len(sys.argv) - 4):
